@@ -1,18 +1,18 @@
 # coding: utf-8
 
-# Copyright 2014-2016 Álvaro Justen <https://github.com/turicas/rows/>
-#
+# Copyright 2014-2019 Álvaro Justen <https://github.com/turicas/rows/>
+
 #    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
+#    it under the terms of the GNU Lesser General Public License as published by
 #    the Free Software Foundation, either version 3 of the License, or
 #    (at your option) any later version.
-#
+
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
+#    GNU Lesser General Public License for more details.
+
+#    You should have received a copy of the GNU Lesser General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import unicode_literals
@@ -21,9 +21,9 @@ from __future__ import unicode_literals
 
 import rows.plugins as plugins
 
-from rows.operations import join, transform, transpose
-from rows.table import Table, FlexibleTable
-from rows.localization import locale_context
+from rows.operations import join, transform, transpose  # NOQA
+from rows.table import Table, FlexibleTable  # NOQA
+from rows.localization import locale_context  # NOQA
 
 
 # Don't have dependencies or dependencies installed on `install_requires`
@@ -67,5 +67,12 @@ if plugins.xlsx:
 if plugins.parquet:
     import_from_parquet = plugins.parquet.import_from_parquet
 
+if plugins.postgresql:
+    import_from_postgresql = plugins.postgresql.import_from_postgresql
+    export_to_postgresql = plugins.postgresql.export_to_postgresql
 
-__version__ = '0.3.1'
+if plugins.pdf:
+    import_from_pdf = plugins.pdf.import_from_pdf
+
+
+__version__ = "0.4.1"
