@@ -1,37 +1,32 @@
 # coding: utf-8
 
-# Copyright 2014-2016 Álvaro Justen <https://github.com/turicas/rows/>
-#
+# Copyright 2014-2019 Álvaro Justen <https://github.com/turicas/rows/>
+
 #    This program is free software: you can redistribute it and/or modify
-#    it under the terms of the GNU General Public License as published by
+#    it under the terms of the GNU Lesser General Public License as published by
 #    the Free Software Foundation, either version 3 of the License, or
 #    (at your option) any later version.
-#
+
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU General Public License for more details.
-#
-#    You should have received a copy of the GNU General Public License
+#    GNU Lesser General Public License for more details.
+
+#    You should have received a copy of the GNU Lesser General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import unicode_literals
 
+import six
+from lxml.html import fromstring as tree_from_string
+
+from rows.plugins.utils import create_table, get_filename_and_fobj
+
 try:
     from HTMLParser import HTMLParser  # Python 2
 except ImportError:
     from html.parser import HTMLParser  # Python 3
 
-import string
-
-import six
-
-from lxml.html import fromstring as tree_from_string
-from lxml.etree import strip_tags
-from lxml.etree import tostring as tree_to_string
-
-from rows.plugins.utils import create_table, get_filename_and_fobj
-
 
 unescape = HTMLParser().unescape
 
@@ -45,11 +40,13 @@ def _get_row_data(fields_xpath):
         for field_name, field_xpath in fields:
             result = row.xpath(field_xpath)
             if result:
-                result = ' '.join(text for text in
-                                    map(six.text_type.strip,
-                                        map(six.text_type,
-                                            map(unescape, result)))
-                                if text)
+                result = " ".join(
+                    text
+                    for text in map(
+                        six.text_type.strip, map(six.text_type, map(unescape, result))
+                    )
+                    if text
+                )
             else:
                 result = None
             data.append(result)
@@ -59,15 +56,15 @@ def _get_row_data(fields_xpath):
     return get_data
 
 
-def import_from_xpath(filename_or_fobj, rows_xpath, fields_xpath,
-                      encoding='utf-8', *args, **kwargs):
+def import_from_xpath(
+    filename_or_fobj, rows_xpath, fields_xpath, encoding="utf-8", *args, **kwargs
+):
 
-    types = set([type(rows_xpath)] + \
-                [type(xpath) for xpath in fields_xpath.values()])
+    types = set([type(rows_xpath)] + [type(xpath) for xpath in fields_xpath.values()])
     if types != set([six.text_type]):
-        raise TypeError('XPath must be {}'.format(six.text_type.__name__))
+        raise TypeError("XPath must be {}".format(six.text_type.__name__))
 
-    filename, fobj = get_filename_and_fobj(filename_or_fobj, mode='rb')
+    filename, fobj = get_filename_and_fobj(filename_or_fobj, mode="rb")
     xml = fobj.read().decode(encoding)
     tree = tree_from_string(xml)
     row_elements = tree.xpath(rows_xpath)
@@ -76,7 +73,5 @@ def import_from_xpath(filename_or_fobj, rows_xpath, fields_xpath,
     row_data = _get_row_data(fields_xpath)
     result_rows = list(map(row_data, row_elements))
 
-    meta = {'imported_from': 'xpath',
-            'filename': filename,
-            'encoding': encoding,}
+    meta = {"imported_from": "xpath", "filename": filename, "encoding": encoding}
     return create_table([header] + result_rows, meta=meta, *args, **kwargs)
